<?php

/*
+---------------------------------------------------------------------------+
| Max Media Manager v0.2                                                    |
| =================                                                         |
|                                                                           |
| Copyright (c) 2003-2005 Awarez Ltd.                                       |
| For contact details, see: http://www.awarez.net/                          |
|                                                                           |
| Copyright (c) 2000-2003 the phpAdsNew developers                          |
| For contact details, see: http://www.phpadsnew.com/                       |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: ck.php 1447 2005-02-06 01:21:42Z scott $
*/

/**
 * @package    MaxDelivery
 * @author     Scott Switzer <scott@switzer.org>
 */

    // Get the required constants and clean the request
    require_once 'init-delivery.php';
    // Get the logging library
    require_once phpAds_path . '/libraries/lib-log.inc.php';
    
    // Convert specially encoded params into the $_REQUEST variable
    convertMaxParams();
    // Remove any special characters
    removeSpecialChars($_REQUEST);
    
    // Get the variables
    $viewerId   = isset($_COOKIE[$conf['var']['viewerId']]) ? $_COOKIE[$conf['var']['viewerId']] : generateUniqueId();
    $adId       = isset($_REQUEST[$conf['var']['adId']]) ? intval($_REQUEST[$conf['var']['adId']]) : 0;
    $zoneId     = isset($_REQUEST[$conf['var']['zoneId']]) ? intval($_REQUEST[$conf['var']['zoneId']]) : 0;
    $creativeId = isset($_REQUEST[$conf['var']['creativeId']]) ? intval($_REQUEST[$conf['var']['creativeId']]) : 0;
    
    if ( ($adId > 0) && ($phpAds_config['log_ad_clicks']) ) {
        // Log the click in the database
        logAdClick($viewerId, $adId, $creativeId, $zoneId);
    }
    // Set the userid cookie
    setcookie($conf['var']['viewerId'], $viewerId, time() + $conf['cookie']['permCookieSeconds']);
    
    // Get the URL that we are going to redirect to
    $destination = _getDestinationUrl($adId);

    // Redirect to the destination url
    Header ("Location: $destination");
    
    // Stop benchmarking
    stopBenchmark();
    
    /**
     * Populate variables from a specially encoded string.  This is used because
     * in a click URL, a parameter could possibly be another URL.
     */
    function convertMaxParams()
    {
        $conf = $GLOBALS['conf'];
        $phpAds_config = $GLOBALS['phpAds_config'];
        
        $qs = $_SERVER['QUERY_STRING'];
        
        // 1.  Strip off the destination
        $dest = false;
        $destStr = $conf['var']['dest'] . '=';
        $pos = strpos($qs, $destStr);
        if ($pos === false) {
            $destStr = 'dest=';
            $pos = strpos($qs, $destStr);
        }
        if ($pos !== false) {
            $dest = urldecode(substr($qs, $pos + strlen($destStr)));
            $qs = substr($qs, 0, $pos);
        }
        
        // 2.  Parse the remaining string
        $aGet = array();
        $paramStr = $conf['var']['params'] . '=';
        if (strpos($qs, $paramStr) === 0) {
            $qs = substr($qs, strlen($paramStr));
            $delim = $qs{0};
            if (is_numeric($delim)) {
                $delim = substr($qs, 1, $delim);
            }
            $qs = substr($qs, strlen($delim) + 1);
            MAX_parse_str($qs, $aGet, $delim);
        } else {
            parse_str($qs, $aGet);
        }
        if ($dest !== false) {
            $aGet[$conf['var']['dest']] = $dest;
        }
        
        // 3.  Add any cookie values to the GET string...
        $n = isset($_GET[$conf['var']['n']]) ? $_GET[$conf['var']['n']] : '';
        if (!empty($n) && !empty($_COOKIE[$conf['var']['vars']][$n])) {
            $vars = unserialize(stripslashes($_COOKIE[$conf['var']['vars']][$n]));
            foreach ($aVars as $name => $value) {
                if (!isset($_GET[$name])) {
                    $_GET[$name] = $value;
                }
            }
        }
        
        $_GET = $aGet;
        $_REQUEST = $_GET + $_POST + $_COOKIE;
    }
     
    /**
     * Get the URL that this click will redirect to.  This method first checks
     * to see if the URL is passed in.  If not, it checks the banner from the cache
     * or database.  As a last resort, it either uses the default banner URL or the referer.
     *
     * @param integer $adId The ID of the advertisement that was clicked
     * @return string The destination URL
     */
    function _getDestinationUrl($adId)
    {
        $conf = $GLOBALS['conf'];
        
        $dest = isset($_REQUEST[$conf['var']['dest']]) ? $_REQUEST[$conf['var']['dest']] : '';
        if (empty($dest)) {
            // Include the DB library
            require_once MAX_LIB . '/db.php';
            // Get the destination from the banner
            $aAd = MAX_getCachedEntity('ad', $adId);
            if (!empty($aAd)) {
                $dest = $aAd['url'];
            }
        }
        if (empty($dest)) {
            $dest = ($adId == 'DEFAULT') ? $phpAds_config['default_banner_target'] : $_SERVER['HTTP_REFERER'];
        }
        
        $aVariables = array();
        $aValidVariables = array (
            $conf['var']['adId'],
            $conf['var']['cacheBuster'],
            $conf['var']['channel'],
            $conf['var']['dest'],
            $conf['var']['logClick'],
            $conf['var']['n'],
            $conf['var']['zoneId']
        );
        
        foreach ($_GET as $name => $value) {
            if (!in_array($name, $aValidVariables)) {
                $aVariables = $name . '=' . $value;
            }
        }
        foreach ($_POST as $name => $value) {
            if (!in_array($name, $aValidVariables)) {
                $aVariables = $name . '=' . $value;
            }
        }
        
        if (!empty($aVariables)) {
            $dest .= ((strpos($dest, '?') > 0) ? '&' : '?') . implode('&', $aVariables);
        }
        
        return $dest;
    }
    
    /**
     * Mimic PHP's parse_str functionality (including decoding values), only allow passing in a delimiter.
     *
     * @param string $qs The string in which to parse
     * @param string $aArr The array in which to store the values
     * @param string $delim The delimiter on which to parse the value
     */
    function MAX_parse_str($qs, &$aArr, $delim = '&')
    {
        $conf = $GLOBALS['conf'];
        $aArr = array();
        // Parse the rest of the array and add to the request array.
        $aElements = explode($delim, $qs);
        foreach($aElements as $element) {
            $len = strpos($element, '=');
            if ($len !== false) {
                $name = substr($element, 0, $len);
                $value = substr($element, $len+1);
                $aArr[$name] = urldecode($value);
            }
        }
    }
?>